summary refs log tree commit diff
path: root/gnu/system.scm
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2016-01-04 22:58:05 +0100
committerLudovic Courtès <ludo@gnu.org>2016-01-05 00:28:42 +0100
commitbe7be9e8dd9411d8d5bcea75c506326393ea2842 (patch)
tree545023ac31364c444f43fa9d5ddff52252218d90 /gnu/system.scm
parent94af9daa73f600f8c96d787f425351c090ffd63f (diff)
downloadguix-be7be9e8dd9411d8d5bcea75c506326393ea2842.tar.gz
services: Move /tmp cleanup to a separate service.
* gnu/services.scm (compute-boot-script): Remove /tmp and /var/run
deletion code from here.
(cleanup-gexp): New procedure with /tmp and /var/run deletion code
formerly in 'compute-boot-script'.
(cleanup-service-type): New variable.
* gnu/system.scm (essential-services): Add an instance of
CLEANUP-SERVICE-TYPE.
Diffstat (limited to 'gnu/system.scm')
-rw-r--r--gnu/system.scm8
1 files changed, 6 insertions, 2 deletions
diff --git a/gnu/system.scm b/gnu/system.scm
index 6dfcc0fe3a..4aedb7ee36 100644
--- a/gnu/system.scm
+++ b/gnu/system.scm
@@ -295,8 +295,12 @@ a container or that of a \"bare metal\" system."
            %boot-service
 
            ;; %DMD-ROOT-SERVICE must come first so that the gexp that execs
-           ;; dmd comes last in the boot script (XXX).
-           %dmd-root-service %activation-service
+           ;; dmd comes last in the boot script (XXX).  Likewise, the cleanup
+           ;; service must come last so that its gexp runs before activation
+           ;; code.
+           %dmd-root-service
+           %activation-service
+           (service cleanup-service-type #f)
 
            (pam-root-service (operating-system-pam-services os))
            (account-service (append (operating-system-accounts os)